==> ejc-probudget-api-3.0.0-20220411.014837-220-sources.jar: com/ejianc/business/budget/vo/SubPayVo.java <==
package com.ejianc.business.budget.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

/**
 * 劳务付款汇总
 */
public class SubPayVo extends BaseVO {

    private static final long serialVersionUID = 1L;

    private Long id;

    // 班组id（供应商id）
    private Long supplierId;
    //班组名称 （供应商）
    private String supplierName;
    //项目id
    private Long projectId;
    //项目名称
    private String projectName;
    //本次申请金额
    private BigDecimal apply;
    //本次申请金额汇总
    private BigDecimal applyTotal;
    //已付款比例 (含本次)
    private BigDecimal yifukuanbili;
    //本次审批金额
    private String approvedAmount;

    //合并行数
    private Integer newKeyRowSpan;

    @Override
    public Long getId() {
        return id;
    }

    @Override
    public void setId(Long id) {
        this.id = id;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public BigDecimal getApply() {
        return apply;
    }

    public void setApply(BigDecimal apply) {
        this.apply = apply;
    }

    public BigDecimal getApplyTotal() {
        return applyTotal;
    }

    public void setApplyTotal(BigDecimal applyTotal) {
        this.applyTotal = applyTotal;
    }

    public BigDecimal getYifukuanbili() {
        return yifukuanbili;
    }

    public void setYifukuanbili(BigDecimal yifukuanbili) {
        this.yifukuanbili = yifukuanbili;
    }

    public String getApprovedAmount() {
        return approvedAmount;
    }

    public void setApprovedAmount(String approvedAmount) {
        this.approvedAmount = approvedAmount;
    }

    public Integer getNewKeyRowSpan() {
        return newKeyRowSpan;
    }

    public void setNewKeyRowSpan(Integer newKeyRowSpan) {
        this.newKeyRowSpan = newKeyRowSpan;
    }
}

==> ejc-probudget-api-3.0.0-20221216.091417-300-sources.jar: com/ejianc/business/budget/vo/SubPayVo.java <==
package com.ejianc.business.budget.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

/**
 * 劳务付款汇总
 */
public class SubPayVo extends BaseVO {

    private static final long serialVersionUID = 1L;

    private Long id;

    // 班组id（供应商id）
    private Long supplierId;
    //班组名称 （供应商）
    private String supplierName;
    //项目id
    private Long projectId;
    //项目名称
    private String projectName;
    //本次申请金额
    private BigDecimal apply;
    //本次申请金额汇总
    private BigDecimal applyTotal;


    //项目所有分包合同已付款	payMnyTotal
    private BigDecimal payMnyTotal;
    //分包过程结算的含本期结算金额	settleTaxMny
    private BigDecimal settleTaxMny;
    //完工结算的结算差额	shouldPayTaxMny
    private BigDecimal shouldPayTaxMny;



    //已付款比例 (含本次)
    private BigDecimal yifukuanbili;
    //本次审批金额
    private String approvedAmount;

    //合并行数
    private Integer newKeyRowSpan;


    public BigDecimal getPayMnyTotal() {
        return payMnyTotal;
    }

    public void setPayMnyTotal(BigDecimal payMnyTotal) {
        this.payMnyTotal = payMnyTotal;
    }

    public BigDecimal getSettleTaxMny() {
        return settleTaxMny;
    }

    public void setSettleTaxMny(BigDecimal settleTaxMny) {
        this.settleTaxMny = settleTaxMny;
    }

    public BigDecimal getShouldPayTaxMny() {
        return shouldPayTaxMny;
    }

    public void setShouldPayTaxMny(BigDecimal shouldPayTaxMny) {
        this.shouldPayTaxMny = shouldPayTaxMny;
    }

    @Override
    public Long getId() {
        return id;
    }

    @Override
    public void setId(Long id) {
        this.id = id;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public BigDecimal getApply() {
        return apply;
    }

    public void setApply(BigDecimal apply) {
        this.apply = apply;
    }

    public BigDecimal getApplyTotal() {
        return applyTotal;
    }

    public void setApplyTotal(BigDecimal applyTotal) {
        this.applyTotal = applyTotal;
    }

    public BigDecimal getYifukuanbili() {
        return yifukuanbili;
    }

    public void setYifukuanbili(BigDecimal yifukuanbili) {
        this.yifukuanbili = yifukuanbili;
    }

    public String getApprovedAmount() {
        return approvedAmount;
    }

    public void setApprovedAmount(String approvedAmount) {
        this.approvedAmount = approvedAmount;
    }

    public Integer getNewKeyRowSpan() {
        return newKeyRowSpan;
    }

    public void setNewKeyRowSpan(Integer newKeyRowSpan) {
        this.newKeyRowSpan = newKeyRowSpan;
    }
}
